#
# spec file for package elisa
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_version 5.10.0
%define kf5_version 5.48.0
%bcond_without lang
Name:           elisa
Version:        20.04.2
Release:        bp153.1.27
Summary:        Music player and collection organizer
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://community.kde.org/Elisa
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Baloo) >= %{kf5_version}
BuildRequires:  cmake(KF5Config) >= %{kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Crash) >= %{kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{kf5_version}
BuildRequires:  cmake(KF5FileMetaData) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5Kirigami2) >= %{kf5_version}
BuildRequires:  cmake(KF5Package) >= %{kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{kf5_version}
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5Multimedia) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5QuickControls2) >= %{qt5_version}
BuildRequires:  cmake(Qt5Sql) >= %{qt5_version}
BuildRequires:  cmake(Qt5Svg) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
Requires:       kdeclarative-components >= %{kf5_version}
Requires:       kirigami2 >= %{kf5_version}
Requires:       libqt5-qtquickcontrols >= %{qt5_version}
Requires:       libqt5-qtquickcontrols2 >= %{qt5_version}
%if %{with lang}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
Recommends:     %{name}-lang

%description
Elisa is a music player with a library where music can be browsed by
album, artist or all tracks. It is indexed using either a private
indexer or an indexer using Baloo. The private one can be configured
to scan music on chosen paths. The Baloo one is faster because Baloo
is providing all needed data from its own database. Playlists can be
built and played.

%lang_package

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif
  %suse_update_desktop_file -r org.kde.elisa Qt KDE AudioVideo Audio Player

%files
%license COPYING*
%doc README*
%doc %lang(en) %{_kf5_htmldir}/en/elisa/
%{_kf5_applicationsdir}/org.kde.elisa.desktop
%{_kf5_appstreamdir}/org.kde.elisa.appdata.xml
%{_kf5_bindir}/elisa
%{_kf5_debugdir}/elisa.categories
%{_kf5_iconsdir}/hicolor/*/apps/elisa.*
%{_kf5_libdir}/elisa/
%{_kf5_qmldir}/org/kde/elisa/

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * fix most issues in Elisa own code detected by Clazy
  * avoid Elisa prevent session close
  * fix qml interface not showing up on Windows due to platform specific qml
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Emit rejected() signal when closing metadata window (kde#420530)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * add automated tests to ViewManager and fix one bug in it
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * workaround not to have the system tray menu appear when it should not (kde#419145)
  * remove dependency on KCMUtils that is no longer used
  * fix move in shuffle move that can trigger an assert and add a test
  * fix handling of menu exported by system tray icon (kde#409010)
  * focus first (title) TextEntry component when editing a radio (kde#418296)
  * add icons to dialogs (kde#418576)
  * keep enough data to check that received data are for the correct track
  * fix invalid URL when sending cover image in mpris for embedded covers (kde#416131)
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * allow to have an Elisa icon in system tray and to close main window (kde#416170)
  * allow the user via to configure Elisa not to rely on Baloo (kde#417822)
  * New shuffle mode for playlist (kde#394333)
  * allow to activate/deactivate the progress indicator on task bar entry (kde#406454)
  * convert KCM based configuration dialog to a simple dialog (kde#414982)
  * Change style in Context view to use blurred album art as the background (kde#417268)
  * Make the album art thumbnails in the playlist a little bit smaller (kde#416806)
  * Migrate from deprecated media content URL API (kde#416144)
  * put back the cleaning of DataModel when database is cleared (kde#413100)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * appdata: use canonical docs.kde.org help location
  * set TextInput::selectByMouse to true to fix text selection
  * limit the rate with which progress is sent via MPRIS (kde#416179)
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Too many changes since 19.12.1, only listing bugfixes:
  * limit the rate with which progress is sent via MPRIS (kde#416179)
  * disable playlist animations to fix display corruption (kde#398093)
  * allow database to contain and get tracks without metadata (kde#415180)
  * fix problems with wrong type passed from qml to c++ (kde#415827)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Too many changes since 19.12.0, only listing bugfixes:
  * set the cover art in the header to a fixed source size (kde#413359)
  * convert KCM based configuration dialog to a simple dialog (kde#414982)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
  * fix new issue introduced by !39 merge request
  * as requested during review, put back extra parameter in TracksListener::trackByFileNameInList
  * many clazy level 2 fixes
  * correct clazy level 1 warnings from Elisa source code
  * should fix the infinite loop when config changed
  * Make it compile against last qt5.14
  * properly get the path in the kcm module and use it cleanly in indexers
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * bring back a working ContextView (kde#412334)
  * call KQuickAddons::QtQuickSettings::init() after QApplication is built
  * add beta release 19.11.80 to appdata file
  * ki18n_install is a noop when the directory does not exist
  * use QtQuickSettings to get common default qml setting
  * put back the cleaning of DataModel when database is cleared (kde#413100)
  * always set new source when track is set
  * always add a slash to the directory path
  * fix one forgotten file modification time and cleanup
* Mon Nov 25 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * Now part of KDE release service
- Run spec-cleaner
* Sun Jun 30 2019 wbauer@tmo.at
- Update to 0.4.2
  * Fix restore of tracks with missing metadata in playlist (this
    was the case for tracks without album metadata)
  * Fix view selector not following the color theme (kde#408435)
* Sat Jun 22 2019 wbauer@tmo.at
- Update to 0.4.1
  * Improve accessibility by providing metadata for UI elements
  * Use full-height separators in ContentView
  * Make Playlist items span full width (kde#408210)
  * Fix focus rectangle not visible in single album view mode
  * Port GridBrowser Delegate UI changes to FileBrowserDelegate too
    (kde#407945)
* Tue May 21 2019 wbauer@tmo.at
- Update to 0.4.0
  * Support for progress bar on Plasma Desktop taskbar entries
  * Improved party mode
  * Undo Support when Playlist is Cleared
  * New Browsing Views: most recently played tracks, most
    frequently played tracks
  * A new context view that is now able to show some of the
    metadata from the currently playing track like the composer,
    lyricist, play count, lyrics ...
  * Optimizations And Reduced Memory Usage
  * Support for Embedded Cover Images
  * Easy Navigation to Album or Artist of the Currently Playing
    Track
  * Improved Grid Views Elements
- Add kirigami2 dependency, which is used/required now also for the
  desktop version
- Run spec-cleaner
* Sun Sep 30 2018 wbauer@tmo.at
- Update to 0.3.0
  * Fix scrolling in the Album, Artist, etc. and Now Playing views
    is much too fast (kde#397446)
  * Fix status box is too small (kde#398924)
  * Fix Elisa being unaware of Baloo if it starts after Elisa
    (kde#387437)
  * User should be able to start typing to search after pressing
    Ctrl+F (kde#398718)
  * Fix high memory usage (kde#396840)
    (improvements have landed in 0.3.0 release and more will come
    to 0.3.1)
  * Elisa should better handle being scaled down to a small size
    (kde#392778)
    (not yet finished but some improvements are in 0.3.0 release)
  * Hide stars when there is no rating
  * Implement interface of Baloo to watch renamed files
  * Upgrade some code using deprecated features in KDeclarative
    framework
  * Align the action buttons with the big icon in the views header
  * Allow the playlist to be hidden when browsing your music
  * Always display the title of the playlist entries
  * Internal improvements to various non graphical components to
    allow future improvements to the header bar
  * Resize track metadata view dynamically
  * Improvements to the header of the play list
  * Add a mode where Elisa can show only the header but in the full
    window
  * Optimize the data methods of model and use
    QAbstractItemModelTester
  * Makes KIO and KFileMetaData be optional dependencies
* Sun Sep 16 2018 wbauer@tmo.at
- Update to 0.2.1
  * Fixed issues that could lead to wrong data shown for albums
    with multiple discs
  * The buttons in the header on top of the views are now aligned
    with the top and bottom of the big icon
- Update to 0.2.0
  * All views are now sorted in ascending order by default
  * New button to toggle between ascending and descending
  * New view allows you to browse your home directory, only music
    files and directories are shown
  * New view allows you to browse by going from genres to artists,
    their albums and its tracks
  * Now has a proper icon
  * The player bar is now featuring all playback controls, the look
    of the playlist view and the views selector have been refreshed
    and improved
  * Now uses the new icons from Breeze to differentiate between
    actions (play, pause, etc) and states (playing, paused, etc)
  * To avoid scanning files for changes at the start, Elisa now
    keeps the last modified time of files
  * The browsing views are now only loaded when shown
  * Elisa is now finding more cover images and most common cases
    should work
  * A few fixes to Mpris2 support
  * Various fixes to the internal tracks database
- Use macros for the minimum Qt5 and KF5 versions in the specfile
* Tue Apr 17 2018 kbabioch@suse.com
- Update to 0.1.1
  * Minor bugfixes
- Download and verify signature for source archive
- Cleaned up spec file (spec-cleaner)
* Sun Apr  8 2018 wbauer@tmo.at
- Update to 0.1
  * First stable release
- Update build requirements
- Add necessary runtime requirements
- Mark license files as %%license instead of %%doc
* Mon Feb  5 2018 jengelh@inai.de
- Ensure neutrality of description.
- Replace vision statement by what the software is about.
* Fri Feb  2 2018 kbabioch@suse.com
- Initial packaging of elisa
